@@ -4,12 +4,12 @@ import os
 from . import analysis
 from .analysis import *
 
+from . import core
+from .core import *
+
 # from . import external
 # from .external import *
 
-from . import framework
-from .framework import *
-
 from . import geometry
 from .geometry import *
 
@@ -30,8 +30,8 @@ __all__ = [
 ]
 
 __all__.extend(analysis.__all__)
+__all__.extend(core.__all__)
 # __all__.extend(external.__all__)
-__all__.extend(framework.__all__)
 __all__.extend(geometry.__all__)
 # __all__.extend(viz.__all__)
 
