@@ -76,6 +76,14 @@ class Trajectory(object):
 
         return result
 
+    # Representation of the object
+    def __repr__(self):
+        return """
+            # structures: {0}
+            # atoms: {1}
+            # dimensions: {2}
+        """.format(self.n_structures, self.n_atoms, self.n_dim)
+
     # Check topology
     def _check_topology(self):
         """
@@ -129,6 +137,13 @@ class Trajectory(object):
 
         pass
 
+    # Describe
+    def describe(self):
+        # print('protein sequence: %s' % self.topology.residues)
+        print('# structures: %s' % self.n_structures)
+        print('# atoms: %s' % self.n_atoms)
+        print('# dimensions: %s' % self.n_dim)
+
     # Get atoms
     def get_atoms(self, index):
         return self.xyz[:, index, :]
